# camelcalc

![Build and Publish](https://github.com/ArmaanT/camelcalc/workflows/Build%20and%20Publish/badge.svg)
[![PyPi Package](https://img.shields.io/pypi/v/camelcalc.svg)](https://pypi.org/project/camelcalc/)

A playable version of [Camel Up](https://en.wikipedia.org/wiki/Camel_Up). As well as a (soon to exist) calculator to help determine what move a team should make.

## Requirements

* Python 3.8+
* Friends to play with

## Installation

Install with pip `pip install camelcalc`

Then play Camel Up by running `camelup`

## Why?

At the end of every semester, the [CIS 120](https://www.seas.upenn.edu/~cis120/current/) TA staff play Camel Up. I've been telling myself that I wanted to attempt to build a calculator for it, so here's my attempt.

## License

See [LICENSE](./LICENSE)
